@@ -19,6 +19,7 @@ from dropbox.files import UploadSessionCursor
 from dropbox.files import WriteMode
 
 from storages.base import BaseStorage
+from storages.utils import get_available_overwrite_name
 from storages.utils import setting
 
 _DEFAULT_TIMEOUT = 100
@@ -48,7 +49,7 @@ class DropboxFile(File):
                 with BytesIO(response.content) as file_content:
                     copyfileobj(file_content, self._file)
             else:
-                # JIC the exception isn't catched by the dropbox client
+                # JIC the exception isn't caught by the dropbox client
                 raise DropboxStorageException(
                     "Dropbox server returned a {} response when accessing {}".format(
                         response.status_code, self.name
@@ -73,7 +74,9 @@ class DropboxStorage(BaseStorage):
     CHUNK_SIZE = 4 * 1024 * 1024
 
     def __init__(self, oauth2_access_token=None, **settings):
-        super().__init__(oauth2_access_token=oauth2_access_token, **settings)
+        if oauth2_access_token is not None:
+            settings["oauth2_access_token"] = oauth2_access_token
+        super().__init__(**settings)
 
         if self.oauth2_access_token is None and not all(
             [self.app_key, self.app_secret, self.oauth2_refresh_token]
@@ -123,9 +126,6 @@ class DropboxStorage(BaseStorage):
         self.client.files_delete(self._full_path(name))
 
     def exists(self, name):
-        if self.write_mode == "overwrite":
-            return False
-
         try:
             return bool(self.client.files_get_metadata(self._full_path(name)))
         except ApiError:
@@ -192,5 +192,11 @@ class DropboxStorage(BaseStorage):
                 )
                 cursor.offset = content.tell()
 
+    def get_available_name(self, name, max_length=None):
+        """Overwrite existing file with the same name."""
+        if self.write_mode == "overwrite":
+            return get_available_overwrite_name(name, max_length)
+        return super().get_available_name(name, max_length)
+
 
 DropBoxStorage = DropboxStorage
