@@ -14,6 +14,7 @@ from storages.base import BaseStorage
 from storages.compress import CompressedFileMixin
 from storages.utils import check_location
 from storages.utils import clean_name
+from storages.utils import get_available_overwrite_name
 from storages.utils import safe_join
 from storages.utils import setting
 from storages.utils import to_bytes
@@ -62,10 +63,9 @@ class GoogleCloudFile(CompressedFileMixin, File):
             )
             if "r" in self._mode:
                 self._is_dirty = False
-                self.blob.download_to_file(self._file)
+                # This automatically decompresses the file
+                self.blob.download_to_file(self._file, checksum="crc32c")
                 self._file.seek(0)
-            if self._storage.gzip and self.blob.content_encoding == "gzip":
-                self._file = self._decompress_file(mode=self._mode, file=self._file)
         return self._file
 
     def _set_file(self, value):
@@ -242,9 +242,6 @@ class GoogleCloudStorage(BaseStorage):
             except NotFound:
                 return False
 
-        if self.file_overwrite:
-            return False
-
         name = self._normalize_name(clean_name(name))
         return bool(self.bucket.get_blob(name))
 
@@ -335,3 +332,9 @@ class GoogleCloudStorage(BaseStorage):
                     params[key] = value
 
             return blob.generate_signed_url(**params)
+
+    def get_available_name(self, name, max_length=None):
+        name = clean_name(name)
+        if self.file_overwrite:
+            return get_available_overwrite_name(name, max_length)
+        return super().get_available_name(name, max_length)
