@@ -4,7 +4,9 @@ import posixpath
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
+from django.core.exceptions import SuspiciousFileOperation
 from django.core.files.utils import FileProxyMixin
+from django.core.files.utils import validate_file_name
 from django.utils.encoding import force_bytes
 
 
@@ -119,6 +121,34 @@ def lookup_env(names):
             return value
 
 
+def get_available_overwrite_name(name, max_length):
+    # This is adapted from Django, and will be removed once
+    # Django 5.1 is the lowest supported version
+    dir_name, file_name = os.path.split(name)
+    if ".." in pathlib.PurePath(dir_name).parts:
+        raise SuspiciousFileOperation(
+            "Detected path traversal attempt in '%s'" % dir_name
+        )
+    validate_file_name(file_name, allow_relative_path=True)
+
+    if max_length is None or len(name) <= max_length:
+        return name
+
+    file_root, file_ext = os.path.splitext(file_name)
+    truncation = len(name) - max_length
+
+    file_root = file_root[:-truncation]
+    if not file_root:
+        raise SuspiciousFileOperation(
+            'Storage tried to truncate away entire filename "%s". '
+            "Please make sure that the corresponding file field "
+            'allows sufficient "max_length".' % name
+        )
+    name = os.path.join(dir_name, "{}{}".format(file_root, file_ext))
+    validate_file_name(name, allow_relative_path=True)
+    return name
+
+
 def is_seekable(file_object):
     return not hasattr(file_object, "seekable") or file_object.seekable()
 
