@@ -14,6 +14,7 @@ from google.cloud.storage.blob import Blob
 from google.cloud.storage.retry import DEFAULT_RETRY
 
 from storages.backends import gcloud
+from storages.backends.gcloud import GoogleCloudFile
 
 
 class GCloudTestCase(TestCase):
@@ -42,7 +43,7 @@ class GCloudStorageTests(GCloudTestCase):
                 self.filename, chunk_size=None
             )
 
-            f.blob.download_to_file = lambda tmpfile: tmpfile.write(data)
+            f.blob.download_to_file = lambda tmpfile, **kwargs: tmpfile.write(data)
             self.assertEqual(f.read(), data)
 
     def test_open_read_num_bytes(self):
@@ -55,7 +56,7 @@ class GCloudStorageTests(GCloudTestCase):
                 self.filename, chunk_size=None
             )
 
-            f.blob.download_to_file = lambda tmpfile: tmpfile.write(data)
+            f.blob.download_to_file = lambda tmpfile, **kwargs: tmpfile.write(data)
             self.assertEqual(f.read(num_bytes), data[0:num_bytes])
 
     def test_open_read_nonexistent(self):
@@ -167,7 +168,6 @@ class GCloudStorageTests(GCloudTestCase):
         )
 
     def test_exists(self):
-        self.storage.file_overwrite = False
         self.storage._bucket = mock.MagicMock()
         self.assertTrue(self.storage.exists(self.filename))
         self.storage._bucket.get_blob.assert_called_with(self.filename)
@@ -187,10 +187,6 @@ class GCloudStorageTests(GCloudTestCase):
         # exists('') should return True if the bucket exists
         self.assertTrue(self.storage.exists(""))
 
-    def test_exists_file_overwrite(self):
-        self.storage.file_overwrite = True
-        self.assertFalse(self.storage.exists(self.filename))
-
     def test_listdir(self):
         file_names = ["some/path/1.txt", "2.txt", "other/path/3.txt", "4.txt"]
         subdir = ""
@@ -520,7 +516,7 @@ class GoogleCloudGzipClientTests(GCloudTestCase):
         """
         Test saving a gzipped file
         """
-        name = "test_storage_save.js.gz"
+        name = "test_storage_save.css.gz"
         content = ContentFile("I am gzip'd", name=name)
 
         blob = Blob("x", None)
@@ -536,7 +532,7 @@ class GoogleCloudGzipClientTests(GCloudTestCase):
                 retry=DEFAULT_RETRY,
                 size=11,
                 predefined_acl=None,
-                content_type="application/javascript",
+                content_type="text/css",
             )
         finally:
             patcher.stop()
@@ -571,3 +567,17 @@ class GoogleCloudGzipClientTests(GCloudTestCase):
             self.assertEqual(zfile.read(), b"I should be gzip'd")
         finally:
             patcher.stop()
+
+    def test_storage_read_gzip(self, *args):
+        """
+        Test reading a gzipped file decompresses content only once.
+        """
+        name = "test_storage_save.css"
+        file = GoogleCloudFile(name, "rb", self.storage)
+        blob = mock.MagicMock()
+        file.blob = blob
+        blob.download_to_file = lambda f, checksum=None: f.write(b"No gzip")
+        blob.content_encoding = "gzip"
+        f = file._get_file()
+
+        f.read()  # This should not fail
